================
``xeofs.single``
================

Methods that investigate relationships or patterns between variables within a single dataset.

.. autosummary::
    :toctree: _autosummary
    :template: custom-class-template.rst
    :recursive:

    ~xeofs.single.EOF
    ~xeofs.single.ComplexEOF
    ~xeofs.single.HilbertEOF
    ~xeofs.single.ExtendedEOF
    ~xeofs.single.POP
    ~xeofs.single.OPA
    ~xeofs.single.GWPCA
    ~xeofs.single.SparsePCA


------------------------------
Sparse Solutions via Rotation
------------------------------

.. autosummary::
    :toctree: _autosummary
    :template: custom-class-template.rst
    :recursive:

    ~xeofs.single.EOFRotator
    ~xeofs.single.ComplexEOFRotator
    ~xeofs.single.HilbertEOFRotator